@@ -91,7 +91,7 @@ public:
      * @see setMandatoryRoles
      * @see setAllowedWeekdays
      */
-    KCalendarCore::Period::List availableSlots() const;
+    Q_REQUIRED_RESULT KCalendarCore::Period::List availableSlots() const;
 
     /**
       Finds a free slot in the future which has at least the same size as
@@ -125,10 +125,10 @@ public Q_SLOTS:
      *
      * These control the timeframe for which conflicts are to be resolved.
      */
-    void setEarliestDate(const QDate &newDate);
-    void setEarliestTime(const QTime &newTime);
-    void setLatestDate(const QDate &newDate);
-    void setLatestTime(const QTime &newTime);
+    void setEarliestDate(QDate newDate);
+    void setEarliestTime(QTime newTime);
+    void setLatestDate(QDate newDate);
+    void setLatestTime(QTime newTime);
 
     void setEarliestDateTime(const QDateTime &newDateTime);
     void setLatestDateTime(const QDateTime &newDateTime);
@@ -175,7 +175,7 @@ private:
     // to prevent the process from being repeated many times
     // after a series of quick parameter changes.
 
-    CalendarSupport::FreeBusyItemModel *mFBModel = nullptr;
+    CalendarSupport::FreeBusyItemModel *const mFBModel;
     QWidget *mParentWidget = nullptr;
 
     QSet<KCalendarCore::Attendee::Role> mMandatoryRoles;
@@ -185,4 +185,3 @@ private:
     int mSlotResolutionSeconds;
 };
 }
-
